@@ -1,18 +1,17 @@
 # coding: utf-8
-from stack import (Stack)
+from stack import Stack
 
 class Context(object):
-    """ Essentially a wrapper around a Stack of dictionaries,
-    this object is used to hold variable information for use in
-    templates. Every {{key}} in a template is looked up within
-    a Context. """
+    """ A wrapper around a Stack of dictionaries, this object is used to hold
+    variable information for use in templates. Every {{key}} in a template is
+    looked up within a Context. """
 
-    default = "" # what to return when no match is found (according to spec)
+    default = '' # what to return when no match is found (according to spec)
     def __init__(self, context=None, **kwargs):
         context = context or {}
         context.update(kwargs)
         self.stack = Stack(context)
-    
+
     def push(self, key):
         return self.stack.push(key)
 
@@ -22,13 +21,9 @@ class Context(object):
     def __call__(self, *args, **kwargs):
         return self.stack(*args, **kwargs)
 
-    def get(self, key, default=""):
-        default = getattr(self, 'default', default)
+    def get(self, key, default=''):
+        default = default or getattr(self, 'default', default)
         return self.get_or_attr(key, default)
-        #attr = self.get_or_attr(key, default)
-        #if hasattr(attr, '__call__'):
-        #    return attr()
-        #return attr
 
     def get_or_attr(self, key, default):
         for ctx in reversed(self.stack):
@@ -45,7 +40,7 @@ class Context(object):
         return self.get(key)
 
     def __repr__(self):
-        return "{}{}".format(self.__class__.__name__, tuple(self.stack))
+        return '%s%s' % (self.__class__.__name__, tuple(self.stack))
 
     def __str__(self):
         return str(self.stack)
